@@ -7,11 +7,16 @@
 #include "tool_rc.h"
 
 #define UNFMT1(x) (x - TPM2_RC_FMT1)
+#define UNVER1(x) (x - TPM2_RC_VER1)
 
 static inline UINT16 tpm2_rc_fmt1_error_get(TPM2_RC rc) {
     return (rc & 0x3F);
 }
 
+static inline UINT16 tpm2_rc_fmt0_error_get(TPM2_RC rc) {
+    return (rc & 0x7F);
+}
+
 static inline UINT8 tss2_rc_layer_format_get(TSS2_RC rc) {
     return ((rc & (1 << 7)) >> 7);
 }
@@ -27,6 +32,17 @@ static tool_rc flatten_fmt1(TSS2_RC rc) {
     }
 }
 
+static tool_rc flatten_fmt0(TSS2_RC rc) {
+
+    UINT8 errnum = tpm2_rc_fmt0_error_get(rc);
+    switch (errnum) {
+    case UNVER1(TPM2_RC_COMMAND_CODE):
+        return tool_rc_unsupported;
+    default:
+        return tool_rc_general_error;
+    }
+}
+
 tool_rc tool_rc_from_tpm(TSS2_RC rc) {
 
     bool is_fmt_1 = tss2_rc_layer_format_get(rc);
@@ -34,5 +50,5 @@ tool_rc tool_rc_from_tpm(TSS2_RC rc) {
         return flatten_fmt1(rc);
     }
 
-    return tool_rc_general_error;
+    return flatten_fmt0(rc);
 }
