@@ -1145,96 +1145,3 @@ TPM2_ALG_ID tpm2_alg_util_get_name_alg(ESYS_CONTEXT *ectx, ESYS_TR handle) {
     Esys_Free(name);
     return name_alg;
 }
-
-tool_rc tpm2_alg_util_sm2_compute_id_digest(ESYS_CONTEXT *ectx, ESYS_TR handle, const char *id, size_t idlen, TPM2B_DIGEST *result) {
-
-    TPMS_ALGORITHM_DETAIL_ECC *parameters = NULL;
-    TPM2B_PUBLIC *public = NULL;
-    TPM2B *id_input = NULL;
-    TPM2B_DIGEST *tmp_digest = NULL;
-
-    if (!id || !result) {
-        return tool_rc_general_error;
-    }
-
-    /* 2-byte id length in bits */
-    if (strlen(id) != idlen) {
-        LOG_ERR("invalid sm2 id!");
-        return tool_rc_general_error;
-    }
-
-    if (idlen > SM2_MAX_ID_LENGTH || idlen <= 0) {
-        LOG_ERR("invalid id length!");
-        return tool_rc_general_error;
-    }
-
-    tool_rc rc = tpm2_geteccparameters(ectx, TPM2_ECC_SM2_P256, &parameters,
-        NULL, TPM2_ALG_NULL);
-    if (rc != tool_rc_success) {
-        LOG_ERR("Could not get ecc parameters!");
-        goto out;
-    }
-
-    rc = tpm2_readpublic(ectx, handle, &public, NULL, NULL);
-    if (rc != tool_rc_success) {
-        LOG_ERR("Could not read public!");
-        goto out;
-    }
-
-    UINT16 key_nbytes = parameters->keySize/8;
-    if (public->publicArea.type != TPM2_ALG_ECC ||
-            public->publicArea.parameters.eccDetail.curveID != TPM2_ECC_SM2_P256 ||
-            public->publicArea.unique.ecc.x.size != key_nbytes ||
-            public->publicArea.unique.ecc.y.size != key_nbytes) {
-        LOG_ERR("invalid sm2 public key!");
-        rc = tool_rc_general_error;
-        goto out;
-    }
-
-    BYTE idbits[2];
-    idbits[0] = ((idlen * 8) >> 8) % 256;
-    idbits[1] = (idlen * 8) % 256;
-
-    UINT16 total_size = sizeof(idbits) + idlen + 6 * key_nbytes;
-
-    id_input = (TPM2B *) calloc(1, sizeof(TPM2B) + total_size);
-    if (id_input == NULL) {
-        LOG_ERR("Could not calloc memory!");
-        rc = tool_rc_general_error;
-        goto out;
-    }
-
-    id_input->size = total_size;
-
-    UINT16 pos = 0;
-    memcpy(id_input->buffer + pos, idbits, sizeof(idbits));
-    pos += sizeof(idbits);
-    memcpy(id_input->buffer + pos, id, idlen);
-    pos += idlen;
-    memcpy(id_input->buffer + pos, parameters->a.buffer, key_nbytes);
-    pos += key_nbytes;
-    memcpy(id_input->buffer + pos, parameters->b.buffer, key_nbytes);
-    pos += key_nbytes;
-    memcpy(id_input->buffer + pos, parameters->gX.buffer, key_nbytes);
-    pos += key_nbytes;
-    memcpy(id_input->buffer + pos, parameters->gY.buffer, key_nbytes);
-    pos += key_nbytes;
-    memcpy(id_input->buffer + pos, public->publicArea.unique.ecc.x.buffer, key_nbytes);
-    pos += key_nbytes;
-    memcpy(id_input->buffer + pos, public->publicArea.unique.ecc.y.buffer, key_nbytes);
-
-    rc = tpm2_hash_compute_data(ectx, TPM2_ALG_SM3_256, TPM2_RH_OWNER,
-                        id_input->buffer, id_input->size, &tmp_digest, NULL);
-    if (rc != tool_rc_success) {
-        goto out;
-    }
-
-    *result = *tmp_digest;
-
-out:
-    free(id_input);
-    Esys_Free(public);
-    Esys_Free(tmp_digest);
-    Esys_Free(parameters);
-    return rc;
-}
