@@ -632,6 +632,14 @@ char *tpm2_util_getenv(const char *name) {
     return getenv(name);
 }
 
+bool tpm2_util_env_yes(const char *name) {
+
+    char *value = getenv(name);
+    return (value && (strcasecmp(value, "yes") == 0 ||
+                      strcasecmp(value, "1") == 0 ||
+                      strcasecmp(value, "true") == 0));
+}
+
 /**
  * Parses a hierarchy value from an option argument.
  * @param value
