@@ -1,14 +1,14 @@
-#!/bin/bash
 
 set -e
 source helpers.sh
 
 start_up
 
-setup_fapi
+CRYPTO_PROFILE="RSA"
+setup_fapi $CRYPTO_PROFILE
 
 function cleanup {
-    tss2_delete --path /
+    tss2 delete --path=/
     shut_down
 }
 
@@ -17,15 +17,15 @@ trap cleanup EXIT
 NV_PATH="/nv/Owner/NvBitmap"
 BITMAP="0x0102030405060608"
 
-tss2_provision
+tss2 provision
 
-tss2_createnv --path $NV_PATH --type "noDa, bitfield" --size 0 --authValue ""
+tss2 createnv --path=$NV_PATH --type="noDa, bitfield" --size=0 --authValue=""
 
-tss2_nvsetbits --nvPath $NV_PATH --bitmap $BITMAP
+tss2 nvsetbits --nvPath=$NV_PATH --bitmap=$BITMAP
 
 expect <<EOF
 # Try with missing nvPath
-spawn tss2_nvsetbits --bitmap $BITMAP
+spawn tss2 nvsetbits --bitmap=$BITMAP
 set ret [wait]
 if {[lindex \$ret 2] || [lindex \$ret 3] != 1} {
     Command has not failed as expected\n"
@@ -35,7 +35,7 @@ EOF
 
 expect <<EOF
 # Try with missing bitmap
-spawn tss2_nvsetbits --nvPath $NV_PATH
+spawn tss2 nvsetbits --nvPath=$NV_PATH
 set ret [wait]
 if {[lindex \$ret 2] || [lindex \$ret 3] != 1} {
     Command has not failed as expected\n"
@@ -45,7 +45,7 @@ EOF
 
 expect <<EOF
 # Try with wrong bitmap
-spawn tss2_nvsetbits --nvPath $NV_PATH --bitmap abc
+spawn tss2 nvsetbits --nvPath=$NV_PATH --bitmap=abc
 set ret [wait]
 if {[lindex \$ret 2] || [lindex \$ret 3] != 1} {
     Command has not failed as expected\n"
@@ -53,4 +53,4 @@ if {[lindex \$ret 2] || [lindex \$ret 3] != 1} {
 }
 EOF
 
-exit 0
\ No newline at end of file
+exit 0
