@@ -843,4 +843,29 @@ tpm2 getrandom 8 --cphash sha1:cp.hash
 file_size=`ls -l cp.hash | awk {'print $5'}`
 test $file_size -eq $expected_hash_len
 
+## Check cpHash output for TPM2_PolicyLocality
+tpm2 startauthsession -S session.dat
+tpm2 policylocality -S session.dat -L policy.dat three --cphash cp.hash
+TPM2_CC_PolicyLocality="0000016f"
+locality="08"
+policySession=$(tpm2 sessionconfig session.dat | grep Session-Handle | \
+    awk -F ' 0x' '{print $2}')
+
+echo -ne $TPM2_CC_PolicyLocality$policySession$locality | xxd -r -p | \
+openssl dgst -sha256 -binary -out test.bin
+cmp cp.hash test.bin 2
+tpm2 flushcontext session.dat
+
+## Check cpHash output for TPM2_PolicyRestart
+tpm2 startauthsession -S session.dat
+tpm2 policyrestart -S session.dat --cphash cp.hash
+TPM2_CC_PolicyRestart="00000180"
+sessionHandle=$(tpm2 sessionconfig session.dat | grep Session-Handle | \
+    awk -F ' 0x' '{print $2}')
+
+echo -ne $TPM2_CC_PolicyRestart$sessionHandle | xxd -r -p | \
+openssl dgst -sha256 -binary -out test.bin
+cmp cp.hash test.bin 2
+tpm2 flushcontext session.dat
+
 exit 0
