@@ -24,20 +24,20 @@ start_up
 cleanup "no-shut-down"
 
 # Sending bytes from stdin (pipe)
-echo -n "return 4" | tpm2_stirrandom -V 2>&1 1>/dev/null | \
+echo -n "return 4" | tpm2 stirrandom -V 2>&1 1>/dev/null | \
 grep -q "Submitting 8 bytes to TPM"
 
 # Sending bytes from stdin (file)
-tpm2_stirrandom -V < "${goodfile}" 2>&1 1>/dev/null | \
+tpm2 stirrandom -V < "${goodfile}" 2>&1 1>/dev/null | \
 grep -q "Submitting 42 bytes to TPM"
 
 # Sending bytes from a file path
-tpm2_stirrandom "${goodfile}" -V 2>&1 1>/dev/null | \
+tpm2 stirrandom "${goodfile}" -V 2>&1 1>/dev/null | \
 grep -q "Submitting 42 bytes to TPM"
 
 # Try to read more than 128 bytes from file and get an error
-if tpm2_stirrandom "${bigfile}"; then
-    echo "tpm2_stirrandom didn't fail on exceeding requested size"
+if tpm2 stirrandom "${bigfile}"; then
+    echo "tpm2 stirrandom didn't fail on exceeding requested size"
     exit 1
 else
     true
