@@ -54,10 +54,54 @@ static tpm2_verifysig_ctx ctx = {
         .pcr_hash = TPM2B_TYPE_INIT(TPM2B_DIGEST, buffer),
 };
 
+/**
+ * Size of the table with the possible padding schemes
+ */
+#define N_PADDING 3
+
+/**
+ * Table with possible padding schemes to guess the one appropriate for
+ * for RSA signature verification
+ */
+static const int rsaPadding[N_PADDING] = { -1 , /*<< no padding */
+                                           RSA_PKCS1_PADDING, RSA_PKCS1_PSS_PADDING };
+
+static bool compare_pcr_selection(TPML_PCR_SELECTION *attest_sel, TPML_PCR_SELECTION *pcr_sel) {
+    if (attest_sel->count != pcr_sel->count) {
+        LOG_ERR("Selection sizes do not match.");
+        return false;
+    }
+    for (uint32_t i = 0; i < attest_sel->count; i++) {
+        for (uint32_t j = 0; j < pcr_sel->count; j++) {
+            if (attest_sel->pcrSelections[i].hash ==
+                pcr_sel->pcrSelections[j].hash) {
+                if (attest_sel->pcrSelections[i].sizeofSelect !=
+                        pcr_sel->pcrSelections[j].sizeofSelect) {
+                    LOG_ERR("Bitmask size does not match");
+                    return false;
+                }
+                if (memcmp(&attest_sel->pcrSelections[i].pcrSelect[0],
+                           &pcr_sel->pcrSelections[j].pcrSelect[0],
+                           attest_sel->pcrSelections[i].sizeofSelect) != 0) {
+                    LOG_ERR("Selection bitmasks do not match");
+                    return false;
+                }
+                break;
+            }
+            if (j == pcr_sel->count - 1) {
+                LOG_ERR("Hash selections to not match.");
+                return false;
+            }
+        }
+    }
+    return true;
+}
+
 static bool verify(void) {
 
     bool result = false;
     EVP_PKEY_CTX *pkey_ctx = NULL;
+    int rc;
 
     /* read the public key */
     EVP_PKEY *pkey = NULL;
@@ -78,39 +122,60 @@ static bool verify(void) {
 #endif
 #endif
 
-    pkey_ctx = EVP_PKEY_CTX_new(pkey, NULL);
-    if (!pkey_ctx) {
-        LOG_ERR("EVP_PKEY_CTX_new failed: %s", ERR_error_string(ERR_get_error(), NULL));
-        goto err;
-    }
-
-    /* get the digest alg */
-    /* TODO SPlit loading on plain vs tss format to detect the hash alg */
-    /* If its a plain sig we need -g */
-    const EVP_MD *md = tpm2_openssl_md_from_tpmhalg(ctx.halg);
-    // TODO error handling
-
-    int rc = EVP_PKEY_verify_init(pkey_ctx);
-    if (!rc) {
-        LOG_ERR("EVP_PKEY_verify_init failed: %s", ERR_error_string(ERR_get_error(), NULL));
-        goto err;
-    }
-
-    rc = EVP_PKEY_CTX_set_signature_md(pkey_ctx, md);
-    if (!rc) {
-        LOG_ERR("EVP_PKEY_CTX_set_signature_md failed: %s", ERR_error_string(ERR_get_error(), NULL));
-        goto err;
-    }
-
     /* TODO dump actual signature */
     tpm2_tool_output("sig: ");
     tpm2_util_hexdump(ctx.signature.buffer, ctx.signature.size);
     tpm2_tool_output("\n");
 
-    // Verify the signature matches message digest
+    /* Try all possible padding schemes for verification */
+    for (int i = 0; i < N_PADDING; i++) {
+        pkey_ctx = EVP_PKEY_CTX_new(pkey, NULL);
+        if (!pkey_ctx) {
+            LOG_ERR("EVP_PKEY_CTX_new failed: %s", ERR_error_string(ERR_get_error(), NULL));
+            goto err;
+        }
 
-    rc = EVP_PKEY_verify(pkey_ctx, ctx.signature.buffer, ctx.signature.size,
-            ctx.msg_hash.buffer, ctx.msg_hash.size);
+        /* get the digest alg */
+        /* TODO SPlit loading on plain vs tss format to detect the hash alg */
+        /* If its a plain sig we need -g */
+        const EVP_MD *md = tpm2_openssl_md_from_tpmhalg(ctx.halg);
+        if (!md) {
+            LOG_ERR("Algorithm not supported: %x", ctx.halg);
+            goto err;
+        }
+
+        rc = EVP_PKEY_verify_init(pkey_ctx);
+        if (!rc) {
+            LOG_ERR("EVP_PKEY_verify_init failed: %s", ERR_error_string(ERR_get_error(), NULL));
+            goto err;
+        }
+
+        rc = EVP_PKEY_CTX_set_signature_md(pkey_ctx, md);
+        if (!rc) {
+            LOG_ERR("EVP_PKEY_CTX_set_signature_md failed: %s", ERR_error_string(ERR_get_error(), NULL));
+            goto err;
+        }
+
+        if (rsaPadding[i] != -1) {
+            rc = EVP_PKEY_CTX_set_rsa_padding(pkey_ctx, rsaPadding[i]);
+            if (rc < 0) {
+                 LOG_ERR("EVP_PKEY_CTX_set_rsa_padding");
+                 goto err;
+            }
+        }
+
+        // Verify the signature matches message digest
+
+        rc = EVP_PKEY_verify(pkey_ctx, ctx.signature.buffer, ctx.signature.size,
+                             ctx.msg_hash.buffer, ctx.msg_hash.size);
+
+        if (rc == 1) {
+            break;
+        } else {
+            EVP_PKEY_CTX_free(pkey_ctx);
+            pkey_ctx = NULL;
+        }
+    }
     if (rc != 1) {
         if (rc == 0) {
             LOG_ERR("Error validating signed message with public key provided");
@@ -128,6 +193,13 @@ static bool verify(void) {
         goto err;
     }
 
+    // check magic
+    if (ctx.attest.magic != TPM2_GENERATED_VALUE) {
+        LOG_ERR("Bad magic, got: 0x%x, expected: 0x%x",
+                ctx.attest.magic, TPM2_GENERATED_VALUE);
+        return false;
+    }
+
     // Also ensure digest from quote matches PCR digest
     if (ctx.flags.pcr) {
         if (!tpm2_util_verify_digests(&ctx.attest.attested.quote.pcrDigest,
@@ -388,7 +460,7 @@ static tool_rc init(void) {
     }
 
     TPM2B_ATTEST *msg = NULL;
-    TPML_PCR_SELECTION pcr_select;
+    TPML_PCR_SELECTION pcr_select = { 0 };
     tpm2_pcrs *pcrs;
     tpm2_pcrs temp_pcrs = {};
     tool_rc return_value = tool_rc_general_error;
@@ -551,6 +623,14 @@ static tool_rc init(void) {
         goto err;
     }
 
+    if (ctx.flags.pcr) {
+        if (!compare_pcr_selection(&ctx.attest.attested.quote.pcrSelect,
+                                   &pcr_select)) {
+            LOG_ERR("PCR selection does not match PCR slection from attest!");
+            goto err;
+        }
+    }
+
     // Figure out the digest for this message
     res = tpm2_openssl_hash_compute_data(ctx.halg, msg->attestationData,
             msg->size, &ctx.msg_hash);
