@@ -546,8 +546,7 @@ static bool get_web_ek_certificate(void) {
     char *ek_uri = encode_ek_public();
     if (!ek_uri) {
         LOG_ERR("Failed to encode EK.");
-        ret = false;
-        goto out;
+        return false;
     }
 
     LOG_INFO("%s", ek_uri);
@@ -560,9 +559,8 @@ static bool get_web_ek_certificate(void) {
     }
 
     ret = retrieve_web_endorsement_certificate(ek_uri);
-
+ out:
     free(ek_uri);
-out:
     return ret;
 }
 
@@ -599,7 +597,7 @@ tool_rc get_tpm_properties(ESYS_CONTEXT *ectx) {
 
     free(capability_data);
     rc = tpm2_getcap(ectx, TPM2_CAP_HANDLES,
-        tpm2_util_hton_32(TPM2_HT_NV_INDEX), TPM2_PT_NV_INDEX_MAX, NULL,
+        TPM2_NV_INDEX_FIRST, TPM2_PT_NV_INDEX_MAX, NULL,
         &capability_data);
     if (rc != tool_rc_success) {
         LOG_ERR("Failed to read capability data for NV indices.");
