@@ -3,6 +3,7 @@
 #include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
+#include <libgen.h>
 
 #include <openssl/err.h>
 #include <openssl/evp.h>
@@ -149,7 +150,8 @@ int main(int argc, char **argv) {
      */
     umask(0117);
 
-    bool is_str_tpm2 = (strcmp(argv[0], "tpm2") == 0);
+    char *argv0 = basename(argv[0]);
+    bool is_str_tpm2 = (strcmp(argv0, "tpm2") == 0);
 
     bool is_one_opt_specified = (argc == 2 && is_str_tpm2);
 
